@@ -5,7 +5,7 @@ The crochetcalculator package
 #__init__.py
 
 # Version of the crochet-calculator package
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
 # Modules
-from .gauge import gauge
\ No newline at end of file
+from .gauge import calculate_gauge
\ No newline at end of file
